function [s, g] = ARspeech(N, flag)
%
% Construct a segment of speech using 4 formants and LF model. Returns also
% the glottal signal
%
%  ----INPUT PARAMETERS----
%    N: how many pitch periods to construct
%    flag: if 1 displays the relation of the amplitude spectrum with phase
%          spectrum of a minimum-phase system.
%
%  ----OUTPUT PARAMENTERS----
%    s: speech output
%
% (c) Yannis Pantazis, 2007, csd, uoc
%     mail: pantazis@csd.uoc.gr

% LF parampeters
Tp = 70;
Te = 85; % must be an integer
Tc = 120; % must be an integer
Ta = 5;
T = 120;  % must be an integer
Ee = 1;

g = LFmodel(Tp, Te, Tc, Ta, T, Ee, N);

% AR parameters
f1 = .96*exp(j*0.09*pi);
f2 = .95*exp(j*0.21*pi);
f3 = .92*exp(j*0.34*pi);
f4 = .9*exp(j*0.45*pi);

a1 = conv([1 -f1], [1 -f1']);
a2 = conv([1 -f2], [1 -f2']);
a3 = conv([1 -f3], [1 -f3']);
a4 = conv([1 -f4], [1 -f4']);

a = conv(conv(conv(a1, a2), a3), a4);
s = filter(1, a, g);
s = s/max(abs(s));   % normalization

if flag
    NFFT = 1024;
    [H, w] = freqz(1,a,NFFT/2);
    H = fft(filter(1,a,[1;zeros(NFFT-1,1)]));
    abH = log(abs(H));
    anH = unwrap(angle(H));

    plot(w, anH(1:NFFT/2));hold on;
    % First way to estimate the angle from the amplitudes
    anH_hat = -hilbert(abH);
    % Second way to estimate the angle from the amplitudes
    s1 = [0;ones(NFFT/2,1);0;-ones(NFFT/2-2,1)];
    anH_hat = -ifft(s1.*fft(abH));
    
    plot(w, imag(anH_hat(1:end/2)),'r--');
end
